Segment Colors
==============

.. automodule:: ngsidekick.segmentcolors
   :members:
   :undoc-members:
   :show-inheritance:

Overview
--------

Tools for managing and applying colors to segments in Neuroglancer.

